@@ -1,22 +1,28 @@
 /*
- * libde265 example application "dec265".
- * Copyright (c) 2013-2014 struktur AG, Dirk Farin <farin@struktur.de>
- *
- * This file is part of dec265, an example application using libde265.
- *
- * dec265 is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * dec265 is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with dec265.  If not, see <http://www.gnu.org/licenses/>.
- */
+  libde265 example application "dec265".
+
+  MIT License
+
+  Copyright (c) 2013-2014 struktur AG, Dirk Farin <farin@struktur.de>
+
+  Permission is hereby granted, free of charge, to any person obtaining a copy
+  of this software and associated documentation files (the "Software"), to deal
+  in the Software without restriction, including without limitation the rights
+  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+  copies of the Software, and to permit persons to whom the Software is
+  furnished to do so, subject to the following conditions:
+
+  The above copyright notice and this permission notice shall be included in all
+  copies or substantial portions of the Software.
+
+  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+  SOFTWARE.
+*/
 
 #define DO_MEMORY_LOGGING 0
 
@@ -106,9 +112,13 @@ static struct option long_options[] = {
 static void write_picture(const de265_image* img)
 {
   static FILE* fh = NULL;
-  if (fh==NULL) { fh = fopen(output_filename, "wb"); }
-
-
+  if (fh==NULL) {
+    if (strcmp(output_filename, "-") == 0) {
+      fh = stdout;
+    } else {
+      fh = fopen(output_filename, "wb");
+    }
+  }
 
   for (int c=0;c<3;c++) {
     int stride;
@@ -584,7 +594,7 @@ int main(int argc, char** argv)
 
   if (optind != argc-1 || show_help) {
     fprintf(stderr," dec265  v%s\n", de265_get_version());
-    fprintf(stderr,"--------------\n");
+    fprintf(stderr,"-----------------\n");
     fprintf(stderr,"usage: dec265 [options] videofile.bin\n");
     fprintf(stderr,"The video file must be a raw bitstream, or a stream with NAL units (option -n).\n");
     fprintf(stderr,"\n");
@@ -659,9 +669,16 @@ int main(int argc, char** argv)
   }
 
 
-  FILE* fh = fopen(argv[optind], "rb");
+  FILE* fh;
+  if (strcmp(argv[optind],"-")==0) {
+    fh = stdin;
+  }
+  else {
+    fh = fopen(argv[optind], "rb");
+  }
+
   if (fh==NULL) {
-    fprintf(stderr,"cannot open file %s!\n", argv[1]);
+    fprintf(stderr,"cannot open file %s!\n", argv[optind]);
     exit(10);
   }
 
