@@ -30,9 +30,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <memory>
-#ifdef HAVE_STDBOOL_H
-#include <stdbool.h>
-#endif
 
 #include "libde265/de265.h"
 #include "libde265/sps.h"
@@ -712,6 +709,10 @@ public:
   // address of first CTB in slice
   void set_SliceAddrRS(int ctbX, int ctbY, int SliceAddrRS)
   {
+    if (ctbX >= ctb_info.width_in_units || ctbY >= ctb_info.height_in_units) {
+      return;
+    }
+
     int idx = ctbX + ctbY*ctb_info.width_in_units;
     ctb_info[idx].SliceAddrRS = SliceAddrRS;
   }
