@@ -901,13 +901,16 @@ de265_error read_scaling_list(bitreader* br, const seq_parameter_set* sps,
       if (!scaling_list_pred_mode_flag) {
         int scaling_list_pred_matrix_id_delta = get_uvlc(br);
 
-	if (sizeId==3) {
-	  // adapt to our changed matrixId for size 3
-	  scaling_list_pred_matrix_id_delta *= 3;
-	}
-	
-        if (scaling_list_pred_matrix_id_delta == UVLC_ERROR ||
-            scaling_list_pred_matrix_id_delta > matrixId) {
+        if (scaling_list_pred_matrix_id_delta == UVLC_ERROR) {
+          return DE265_ERROR_CODED_PARAMETER_OUT_OF_RANGE;
+        }
+
+        if (sizeId == 3) {
+          // adapt to our changed matrixId for size 3
+          scaling_list_pred_matrix_id_delta *= 3;
+        }
+
+        if (scaling_list_pred_matrix_id_delta > matrixId) {
           return DE265_ERROR_CODED_PARAMETER_OUT_OF_RANGE;
         }
 
